@@ -14,19 +14,19 @@ def get_logger(name: str) -> logging.Logger:
     logging.captureWarnings(True)
     logger = logging.getLogger(name)
     logger.setLevel(logging.DEBUG)
-    if not logger.hasHandlers():
-        handler = logging.StreamHandler()
-        handler.setFormatter(
-            logging.Formatter(
-                '[%(asctime)s] %(threadName)s %(name)s'
-                ' [%(levelname)7s] %(message)s'
-            )
+    if logger.hasHandlers():
+        return logger
+    handler = logging.StreamHandler()
+    handler.setFormatter(
+        logging.Formatter(
+            "[%(asctime)s] %(threadName)s %(name)s [%(levelname)7s] %(message)s"
         )
-        logger.addHandler(handler)
+    )
+    logger.addHandler(handler)
     return logger
 
 
-def get_logger_json(name: str = 'logger') -> logging.Logger:
+def get_logger_json(name: str = "logger") -> logging.Logger:
     """Function to get a new logger instance"""
     log = logging.getLogger(name)
     log.setLevel(logging.INFO)
@@ -47,24 +47,25 @@ class JsonLogFormatter(jsonlogger.JsonFormatter):
     """Json Log formatter following the Zooplus standards."""
 
     def add_fields(
-            self,
-            log_record: dict[str, Literal],
-            record: logging.LogRecord,
-            message_dict: dict[str, str]
+        self,
+        log_record: dict[str, Literal],
+        record: logging.LogRecord,
+        message_dict: dict[str, str],
     ) -> None:
+        """Adding json fields for logging"""
         super().add_fields(log_record, record, message_dict)
 
-        log_record['log_type'] = 'application_log'
-        log_record['@timestamp'] = dt.datetime.now(dt.timezone.utc).isoformat()
-        log_record['description'] = log_record.pop('message', None)
-        log_record['severity'] = record.levelname.upper()
-        log_record['class'] = ':'.join(
+        log_record["log_type"] = "application_log"
+        log_record["@timestamp"] = dt.datetime.now(dt.timezone.utc).isoformat()
+        log_record["description"] = log_record.pop("message", None)
+        log_record["severity"] = record.levelname.upper()
+        log_record["class"] = ":".join(
             [record.module, record.funcName, str(record.lineno)]
         )
 
-        if exc_info := log_record.pop('exc_info', None):
-            log_record['stacktrace'] = exc_info
+        if exc_info := log_record.pop("exc_info", None):
+            log_record["stacktrace"] = exc_info
         if record.process:
-            log_record['pid'] = record.process
+            log_record["pid"] = record.process
         if record.threadName:
-            log_record['thread'] = record.threadName
+            log_record["thread"] = record.threadName
